@@ -19,9 +19,7 @@
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -268,6 +266,10 @@ wnck_pager_class_init (WnckPagerClass *klass)
   widget_class->drag_data_get = wnck_pager_drag_data_get;
   widget_class->drag_end = wnck_pager_drag_end;
   widget_class->query_tooltip = wnck_pager_query_tooltip;
+
+#if GTK_CHECK_VERSION (3, 19, 1)
+  gtk_widget_class_set_css_name (widget_class, "wnck-pager");
+#endif
 }
 
 static void
@@ -405,8 +407,8 @@ _wnck_pager_get_padding (WnckPager *pager,
       GtkStateFlags    state;
 
       widget = GTK_WIDGET (pager);
-      state = gtk_widget_get_state_flags (widget);
       context = gtk_widget_get_style_context (widget);
+      state = gtk_style_context_get_state (context);
       gtk_style_context_get_padding (context, state, padding);
     }
   else
@@ -507,7 +509,6 @@ wnck_pager_size_request  (GtkWidget      *widget,
   int workspace_width, workspace_height;
   int n_rows;
   GtkBorder padding;
-  int focus_width;
 
   pager = WNCK_PAGER (widget);
 
@@ -553,12 +554,6 @@ wnck_pager_size_request  (GtkWidget      *widget,
   _wnck_pager_get_padding (pager, &padding);
   requisition->width += padding.left + padding.right;
   requisition->height += padding.top + padding.bottom;
-
-  gtk_widget_style_get (widget,
-			"focus-line-width", &focus_width,
-			NULL);
-  requisition->width  += 2 * focus_width;
-  requisition->height += 2 * focus_width;
 }
 
 static GtkSizeRequestMode
@@ -597,7 +592,6 @@ wnck_pager_get_preferred_width_for_height (GtkWidget *widget,
   int n_rows;
   int spaces_per_row;
   int workspace_width, workspace_height;
-  int focus_width;
   GtkBorder padding;
   int width = 0;
 
@@ -623,12 +617,6 @@ wnck_pager_get_preferred_width_for_height (GtkWidget *widget,
       spaces_per_row = 1;
     }
 
-  gtk_widget_style_get (widget,
-			"focus-line-width", &focus_width,
-			NULL);
-  height -= 2 * focus_width;
-  width += 2 * focus_width;
-
   _wnck_pager_get_padding (pager, &padding);
   height -= padding.top + padding.bottom;
   width += padding.left + padding.right;
@@ -666,7 +654,6 @@ wnck_pager_get_preferred_height_for_width (GtkWidget *widget,
   int n_rows;
   int spaces_per_row;
   int workspace_width, workspace_height;
-  int focus_width;
   GtkBorder padding;
   int height = 0;
 
@@ -692,12 +679,6 @@ wnck_pager_get_preferred_height_for_width (GtkWidget *widget,
       spaces_per_row = 1;
     }
 
-  gtk_widget_style_get (widget,
-			"focus-line-width", &focus_width,
-			NULL);
-  width -= 2 * focus_width;
-  height += 2 * focus_width;
-
   _wnck_pager_get_padding (pager, &padding);
   width -= padding.left + padding.right;
   height += padding.top + padding.bottom;
@@ -725,18 +706,14 @@ wnck_pager_size_allocate (GtkWidget      *widget,
 {
   WnckPager *pager;
   int workspace_size;
-  int focus_width;
   GtkBorder padding;
   int width;
   int height;
 
   pager = WNCK_PAGER (widget);
 
-  gtk_widget_style_get (GTK_WIDGET (pager),
-			"focus-line-width", &focus_width,
-			NULL);
-  width  = allocation->width  - 2 * focus_width;
-  height = allocation->height - 2 * focus_width;
+  width = allocation->width;
+  height = allocation->height;
 
   _wnck_pager_get_padding (pager, &padding);
   width  -= padding.left + padding.right;
@@ -784,16 +761,23 @@ get_workspace_rect (WnckPager    *pager,
   int col, row;
   GtkAllocation allocation;
   GtkBorder padding;
-  int focus_width;
 
   widget = GTK_WIDGET (pager);
 
   gtk_widget_get_allocation (widget, &allocation);
 
+  if (allocation.x < 0 || allocation.y < 0 ||
+      allocation.width < 0 || allocation.height < 0)
+    {
+      rect->x = 0;
+      rect->y = 0;
+      rect->width = 0;
+      rect->height = 0;
+
+      return;
+    }
+
   _wnck_pager_get_padding (pager, &padding);
-  gtk_widget_style_get (widget,
-			"focus-line-width", &focus_width,
-			NULL);
 
   if (!pager->priv->show_all_workspaces)
     {
@@ -803,10 +787,10 @@ get_workspace_rect (WnckPager    *pager,
 
       if (active_space && space == wnck_workspace_get_number (active_space))
 	{
-	  rect->x = focus_width + padding.left;
-	  rect->y = focus_width + padding.top;
-	  rect->width = allocation.width - 2 * focus_width - padding.left - padding.right;
-	  rect->height = allocation.height - 2 * focus_width - padding.top - padding.bottom;
+	  rect->x = padding.left;
+	  rect->y = padding.top;
+	  rect->width = allocation.width - padding.left - padding.right;
+	  rect->height = allocation.height - padding.top - padding.bottom;
 	}
       else
 	{
@@ -819,8 +803,8 @@ get_workspace_rect (WnckPager    *pager,
       return;
     }
 
-  hsize = allocation.width - 2 * focus_width;
-  vsize = allocation.height - 2 * focus_width;
+  hsize = allocation.width;
+  vsize = allocation.height;
 
   if (pager->priv->shadow_type != GTK_SHADOW_NONE)
     {
@@ -874,9 +858,6 @@ get_workspace_rect (WnckPager    *pager,
 	rect->height = vsize - rect->y;
     }
 
-  rect->x += focus_width;
-  rect->y += focus_width;
-
   if (pager->priv->shadow_type != GTK_SHADOW_NONE)
     {
       rect->x += padding.left;
@@ -1124,23 +1105,14 @@ workspace_at_point (WnckPager *pager,
   int i;
   int n_spaces;
   GtkAllocation allocation;
-  int focus_width;
   GtkBorder padding;
 
   widget = GTK_WIDGET (pager);
 
   gtk_widget_get_allocation (widget, &allocation);
 
-  gtk_widget_style_get (GTK_WIDGET (pager),
-			"focus-line-width", &focus_width,
-			NULL);
   _wnck_pager_get_padding (pager, &padding);
 
-  padding.left += focus_width;
-  padding.right += focus_width;
-  padding.top += focus_width;
-  padding.bottom += focus_width;
-
   n_spaces = wnck_screen_get_workspace_count (pager->priv->screen);
 
   i = 0;
@@ -1449,7 +1421,6 @@ wnck_pager_draw (GtkWidget *widget,
   gboolean first;
   GtkStyleContext *context;
   GtkStateFlags state;
-  int focus_width;
 
   pager = WNCK_PAGER (widget);
 
@@ -1460,9 +1431,7 @@ wnck_pager_draw (GtkWidget *widget,
 
   state = gtk_widget_get_state_flags (widget);
   context = gtk_widget_get_style_context (widget);
-  gtk_widget_style_get (widget,
-			"focus-line-width", &focus_width,
-			NULL);
+
   gtk_style_context_save (context);
   gtk_style_context_set_state (context, state);
 
@@ -1479,11 +1448,9 @@ wnck_pager_draw (GtkWidget *widget,
   if (pager->priv->shadow_type != GTK_SHADOW_NONE)
     {
       cairo_save (cr);
-      gtk_render_frame (context, cr,
-			focus_width,
-			focus_width,
-                        gtk_widget_get_allocated_width (widget) - 2 * focus_width,
-                        gtk_widget_get_allocated_height (widget) - 2 * focus_width);
+      gtk_render_frame (context, cr, 0, 0,
+                        gtk_widget_get_allocated_width (widget),
+                        gtk_widget_get_allocated_height (widget));
       cairo_restore (cr);
     }
 
